translate.storage.rc.rcfile

Package translate :: Package storage :: Module rc :: Class rcfile |
[hide private]
[frames] | no frames]

# Class rcfile

source code

This class represents a .rc file, made up of rcunits.

Nested Classes | [hide private]
| UnitClass The class of units that will be instantiated and used by this class

Instance Methods | [hide private]
__init__(self, inputfile=None, lang=None, sublang=None) Construct an rcfile, optionally reading in from inputfile. | source code
parse(self, rcsrc) Read the source of a .rc file in and include them as units. | source code
__str__(self) convert the units back to lines | source code
Inherited from `base.TranslationStore`: `__getstate__`, `__setstate__`, `add_unit_to_index`, `addsourceunit`, `addunit`, `findid`, `findunit`, `findunits`, `getsourcelanguage`, `gettargetlanguage`, `getunits`, `isempty`, `makeindex`, `remove_unit_from_index`, `require_index`, `save`, `savefile`, `setsourcelanguage`, `settargetlanguage`, `translate`, `unit_iter` Inherited from `base.TranslationStore` (private): `_assignname` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`

Class Methods | [hide private]
Inherited from `base.TranslationStore`: `parsefile`, `parsestring`

Class Variables | [hide private]
Inherited from `base.TranslationStore`: `Extensions`, `Mimetypes`, `Name`, `suggestions_in_format` Inherited from `base.TranslationStore` (private): `_binary`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, inputfile=None, lang=None, sublang=None) (Constructor) | source code
Construct an rcfile, optionally reading in from inputfile. Overrides: object.__init__

### parse(self, rcsrc) | source code
Read the source of a .rc file in and include them as units. Overrides: base.TranslationStore.parse

### __str__(self) (Informal representation operator) | source code
convert the units back to lines Overrides: object.__str__